%define abi_ver 2.2.0
%global desc %{expand: \
The Global Extensible Open Power Manager (GEOPM) provides a framework to
explore power and energy optimizations on platforms with heterogeneous mixes
of computing hardware.

Users can monitor their system's energy and power consumption, and safely
optimize system hardware settings to achieve energy efficiency and/or
performance objectives.}

Name:		libgeopm
Version:	3.2.0
Release:	%autorelease
Summary:	C/C++ implementation of the GEOPM runtime service

License:	BSD-3-Clause
URL:		https://geopm.github.io
Source0:	https://github.com/geopm/geopm/archive/v%{version}/geopm-%{version}.tar.gz

BuildRequires:	autoconf
BuildRequires:	automake
BuildRequires:	gcc-c++
BuildRequires:	gmock-devel
BuildRequires:	gtest-devel
BuildRequires:	libtool
BuildRequires:	elfutils-libelf-devel
BuildRequires:	libgeopmd-devel

%description
%{desc}

%package devel
Summary:	Development files for %{name}
Requires:	libgeopmd-devel
Requires:	%{name}%{?_isa} = %{version}-%{release}

%description devel
The %{name}-devel package contains libraries and header files for
applications that use %{name}.

%package -n geopm-cli
Summary:	The libgeopm command-line tools
Requires:	%{name}%{?_isa} = %{version}-%{release}
Requires:	geopmd
Requires:	python3dist(geopmpy)

%description -n geopm-cli
%{desc}

%prep
%autosetup -p1 -n geopm-%{version}

pushd %{name}
echo %{version} > VERSION
autoreconf -vif
popd

%build
pushd %{name}
# Filter out -Wnon-virtual-dtor from CFLAGS
export CFLAGS="$CFLAGS -Wno-non-virtual-dtor"
%configure \
	--disable-build-gtest \
	--disable-mpi \
	--disable-openmp \
	--disable-fortran \
	--disable-geopmd-local \
	|| ( cat config.log && false )
%make_build
popd

%install
pushd %{name}
%make_install
rm -v %{buildroot}/%{_libdir}/libgeopm.a
rm -v %{buildroot}/%{_libdir}/libgeopm.la
rm -v %{buildroot}/%{_libdir}/geopm/libgeopmiogroup_profile.a
rm -v %{buildroot}/%{_libdir}/geopm/libgeopmiogroup_profile.la
rm -v %{buildroot}/%{_libdir}/geopm/libgeopmiogroup_profile.so
rm -v %{buildroot}/%{_libdir}/geopm/libgeopmiogroup_profile.so.2
%if "%{_bindir}" != "%{_sbindir}"
mkdir -p %{buildroot}%{_sbindir}
mv %{buildroot}{%{_bindir},%{_sbindir}}/geopmadmin
%endif
popd

%check
%if ! %{defined _without_check}
pushd %{name}
make check || (cat ./test-suite.log && false)
popd
%endif

%files
%license LICENSE-BSD-3-Clause
%doc CONTRIBUTING.rst README.md
%doc %{_docdir}/%{name}/LICENSE-BSD-3-Clause
%doc %{_docdir}/%{name}/VERSION
%{_libdir}/%{name}.so.%{abi_ver}
%{_libdir}/%{name}.so.2
%{_libdir}/geopm
%{_libdir}/geopm/libgeopmiogroup_profile.so.%{abi_ver}

%files devel
%{_includedir}/geopm
%{_includedir}/geopm_*
%{_libdir}/%{name}.so

%files -n geopm-cli
%{_sbindir}/geopmadmin
%{_bindir}/geopmagent
%{_bindir}/geopmctl

%changelog
%autochangelog
